
'''
Functions and classes for course Machine Learning and Data Mining
'''

def multiplication(x,y):
    '''Multiplies 2 numbers'''
    return x*y

def addition(x,y):
    '''Adds 2 numbers'''
    return x+y

def subtraction(x,y):
    '''Subtracts 2 numbers'''
    return x-y
